import AbstractLogger from "./loggers/abstract/abstract-logger";
import { INamedLogger, LoggerConfiguration, SessionLogsStorage } from "./types";
export declare const LogsStorage: SessionLogsStorage;
export default class Logger {
    /**
     * Get browser logger instance
     */
    static get browser(): AbstractLogger;
    /**
     * Get node logger instance as AbstractLogger type
     * If not defined, runtime error will raise without typescript error due type assertion
     */
    static get unsafeNode(): AbstractLogger;
    /**
     * Safely get node logger
     *
     * This method will require manual check for node logger to be defined
     */
    static get node(): AbstractLogger | undefined;
    /**
     * Get named logger
     *
     * @param namespace
     */
    static named(namespace: string): INamedLogger;
    /**
     * Asynchronously import node logger and write it into memory
     *
     * @param config default configuration, optional
     */
    static setupNodeLogger(config?: LoggerConfiguration): Promise<void>;
    /**
     * Changes default logger, used by Logger.* log methods
     *
     * Default is browser logger
     *
     * @param logger
     */
    static setDefaultLogger(logger: AbstractLogger): void;
    /**
     * Reconfigure all defined loggers
     *
     * @param config new configuration
     */
    static reconfigure(config: LoggerConfiguration): void;
    /**
     * Anonymous informational log
     *
     * @param message log message
     */
    static info(...message: any): {
        json: ((message: string) => import("./types").PossibleInputs) | import("./types").PossibleInputs;
    };
    /**
     * Signed informational log
     *
     * @param from sender
     * @param message log message
     */
    static infoFrom(from: string, ...message: any): {
        json: ((message: string) => import("./types").PossibleInputs) | import("./types").PossibleInputs;
    };
    /**
     * Anonymous warning log
     *
     * @param message log message
     */
    static warning(...message: any): {
        json: ((message: string) => import("./types").PossibleInputs) | import("./types").PossibleInputs;
    };
    /**
     * Signed warning log
     *
     * @param from sender
     * @param message log message
     */
    static warningFrom(from: string, ...message: any): {
        json: ((message: string) => import("./types").PossibleInputs) | import("./types").PossibleInputs;
    };
    /**
     * Anonymous error log
     *
     * @param message log message
     */
    static error(...message: any): {
        json: ((message: string) => import("./types").PossibleInputs) | import("./types").PossibleInputs;
    };
    /**
     * Signed error log
     *
     * @param from sender
     * @param message log message
     */
    static errorFrom(from: string, ...message: any): {
        json: ((message: string) => import("./types").PossibleInputs) | import("./types").PossibleInputs;
    };
    /**
     * Anonymous success log
     *
     * @param message log message
     */
    static success(...message: any): {
        json: ((message: string) => import("./types").PossibleInputs) | import("./types").PossibleInputs;
    };
    /**
     * Signed success log
     *
     * @param from sender
     * @param message log message
     */
    static successFrom(from: string, ...message: any): {
        json: ((message: string) => import("./types").PossibleInputs) | import("./types").PossibleInputs;
    };
    /**
     * Export stored logs
     */
    static exportStoredLogs(): SessionLogsStorage;
}
