"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogsStorage = void 0;
const browser_logger_1 = __importDefault(require("./loggers/browser-logger"));
exports.LogsStorage = Array();
const DefaultLoggers = {
    browser: new browser_logger_1.default({
        storage: exports.LogsStorage
    })
};
class Logger {
    /**
     * Get browser logger instance
     */
    static get browser() {
        return DefaultLoggers.browser;
    }
    /**
     * Get node logger instance as AbstractLogger type
     * If not defined, runtime error will raise without typescript error due type assertion
     */
    static get unsafeNode() {
        return DefaultLoggers.node;
    }
    /**
     * Safely get node logger
     *
     * This method will require manual check for node logger to be defined
     */
    static get node() {
        return DefaultLoggers.node;
    }
    /**
     * Get named logger
     *
     * @param namespace
     */
    static named(namespace) {
        return {
            /**
             * Signed info log
             * @param message log message
             */
            info: (...message) => this.infoFrom(namespace, ...message),
            warning: (...message) => this.warningFrom(namespace, ...message),
            /**
             * Signed error log
             * @param message log message
             */
            error: (...message) => this.errorFrom(namespace, ...message),
            /**
             * Signed success log
             * @param message log message
             */
            success: (...message) => this.successFrom(namespace, ...message),
        };
    }
    /**
     * Asynchronously import node logger and write it into memory
     *
     * @param config default configuration, optional
     */
    static async setupNodeLogger(config) {
        const NodeLogger = await Promise.resolve().then(() => __importStar(require("./loggers/node-logger")));
        DefaultLoggers.node = new NodeLogger.NodeLogger({
            storage: exports.LogsStorage,
            ...config ?? {}
        });
    }
    /**
     * Changes default logger, used by Logger.* log methods
     *
     * Default is browser logger
     *
     * @param logger
     */
    static setDefaultLogger(logger) {
        DefaultLoggers.default = logger;
    }
    /**
     * Reconfigure all defined loggers
     *
     * @param config new configuration
     */
    static reconfigure(config) {
        DefaultLoggers.node?.reconfigure(config);
        DefaultLoggers.browser.reconfigure(config);
        DefaultLoggers.default?.reconfigure(config);
    }
    /**
     * Anonymous informational log
     *
     * @param message log message
     */
    static info(...message) {
        const logger = DefaultLoggers.default ?? DefaultLoggers.browser;
        return logger.info(...message);
    }
    /**
     * Signed informational log
     *
     * @param from sender
     * @param message log message
     */
    static infoFrom(from, ...message) {
        const logger = DefaultLoggers.default ?? DefaultLoggers.browser;
        return logger.infoFrom(from, ...message);
    }
    /**
     * Anonymous warning log
     *
     * @param message log message
     */
    static warning(...message) {
        const logger = DefaultLoggers.default ?? DefaultLoggers.browser;
        return logger.warning(...message);
    }
    /**
     * Signed warning log
     *
     * @param from sender
     * @param message log message
     */
    static warningFrom(from, ...message) {
        const logger = DefaultLoggers.default ?? DefaultLoggers.browser;
        return logger.warningFrom(from, ...message);
    }
    /**
     * Anonymous error log
     *
     * @param message log message
     */
    static error(...message) {
        const logger = DefaultLoggers.default ?? DefaultLoggers.browser;
        return logger.error(...message);
    }
    /**
     * Signed error log
     *
     * @param from sender
     * @param message log message
     */
    static errorFrom(from, ...message) {
        const logger = DefaultLoggers.default ?? DefaultLoggers.browser;
        return logger.errorFrom(from, ...message);
    }
    /**
     * Anonymous success log
     *
     * @param message log message
     */
    static success(...message) {
        const logger = DefaultLoggers.default ?? DefaultLoggers.browser;
        return logger.success(...message);
    }
    /**
     * Signed success log
     *
     * @param from sender
     * @param message log message
     */
    static successFrom(from, ...message) {
        const logger = DefaultLoggers.default ?? DefaultLoggers.browser;
        return logger.successFrom(from, ...message);
    }
    /**
     * Export stored logs
     */
    static exportStoredLogs() {
        return JSON.parse(JSON.stringify(exports.LogsStorage));
    }
}
exports.default = Logger;
