"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const types_1 = require("../../types");
class AbstractLogger {
    config;
    constructor(config) {
        this.config = config;
    }
    reconfigure(config) {
        this.config = { ...this.config, ...config };
        return this;
    }
    info(...message) {
        return this.log(types_1.LogLevel.INFO, message);
    }
    infoFrom(from, ...message) {
        return this.log(types_1.LogLevel.INFO, message, from);
    }
    warning(...message) {
        return this.log(types_1.LogLevel.WARNING, message);
    }
    warningFrom(from, ...message) {
        return this.log(types_1.LogLevel.WARNING, message, from);
    }
    error(...message) {
        return this.log(types_1.LogLevel.ERROR, message);
    }
    errorFrom(from, ...message) {
        return this.log(types_1.LogLevel.ERROR, message, from);
    }
    success(...message) {
        return this.log(types_1.LogLevel.SUCCESS, message);
    }
    successFrom(from, ...message) {
        return this.log(types_1.LogLevel.SUCCESS, message, from);
    }
    getJsonResponse(message, logLevel, from) {
        const self = this;
        return {
            set json(data) {
                self.jsonLog(typeof data === "function" ? data(message.map(m => typeof m === "object" ? JSON.stringify(m) : m).join(" ")) : data, logLevel, from);
            }
        };
    }
    jsonLog(message, level, module) {
        if (!this.config.json)
            return;
        let _module = module ?? "system";
        let _message = message;
        if (typeof message === "object" && "__module" in message) {
            const { __module, ...rest } = message;
            if (__module) {
                _module = __module;
                _message = rest;
            }
        }
        if (this.config.storage)
            this.config.storage.push({ level, timestamp: Date.now(), message: JSON.stringify(message) });
        console.info(JSON.stringify({
            module: _module ?? "system",
            level,
            timestamp: Date.now(),
            data: typeof _message !== "object" ? { _message } : _message
        }));
    }
}
exports.default = AbstractLogger;
