"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const abstract_logger_1 = __importDefault(require("./abstract/abstract-logger"));
const types_1 = require("../types");
class BrowserLogger extends abstract_logger_1.default {
    constructor(config) {
        super(config);
    }
    log(logLevel, message, from) {
        if (this.config.json)
            return this.getJsonResponse(message, logLevel, from);
        const messageColor = {
            [types_1.LogLevel.WARNING]: ["orange", "black"],
            [types_1.LogLevel.ERROR]: ["red", "white"],
            [types_1.LogLevel.INFO]: ["cornflowerblue", "black"],
            [types_1.LogLevel.SUCCESS]: ["green", "white"]
        }[logLevel];
        if (this.config.showPrefix === false) {
            console.log(...message);
            return this.getJsonResponse(message, logLevel, from);
        }
        const datePrefix = new Date().toLocaleDateString("en-US");
        const timePrefix = new Date().toLocaleTimeString("en-US", { hour12: false });
        const combinedPrefix = new Date().toISOString();
        const prefix = Boolean(this.config.attachPrefixDate && this.config.attachPrefixTime)
            ? combinedPrefix
            : this.config.attachPrefixDate ? datePrefix
                : this.config.attachPrefixTime ? timePrefix
                    : undefined;
        const override = this.config.overrideMessageOutput;
        const nextMessage = override ? override(logLevel, message, from) : [
            [
                prefix ? `%c${prefix}` : "",
                `%c${logLevel.toUpperCase()}`,
                from ? `%c ${from} ` : "",
                "%c",
                ...message
            ].filter(Boolean).join(" ").replace(/\s{2,}/g, " ").trim(),
            prefix ? "color: gray" : "",
            `color: ${messageColor[0]}`,
            from ? `color: ${messageColor[1]}; background: ${messageColor[0]}` : "",
            "color: unset"
        ].filter(Boolean);
        console.log(...nextMessage);
        this.config.storage?.push({
            timestamp: Date.now(),
            level: logLevel,
            message: message.map(i => typeof i === "object" ? JSON.stringify(i) : i).join(" ")
        });
        return this.getJsonResponse(message, logLevel, from);
    }
}
exports.default = BrowserLogger;
