"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeLogger = void 0;
const safe_1 = __importDefault(require("colors/safe"));
const types_1 = require("../types");
const abstract_logger_1 = __importDefault(require("./abstract/abstract-logger"));
class NodeLogger extends abstract_logger_1.default {
    constructor(config) {
        super(config);
    }
    log(logLevel, message, from) {
        if (this.config.json)
            return this.getJsonResponse(message, logLevel, from);
        safe_1.default.enable();
        const messageColor = {
            [types_1.LogLevel.WARNING]: "yellow",
            [types_1.LogLevel.ERROR]: "red",
            [types_1.LogLevel.INFO]: "cyan",
            [types_1.LogLevel.SUCCESS]: "green"
        }[logLevel];
        if (this.config.showPrefix === false) {
            console.log(...message);
            safe_1.default.disable();
            return this.getJsonResponse(message, logLevel, from);
        }
        const fgColor = (msg) => safe_1.default[messageColor](msg);
        const bgColor = (msg) => safe_1.default["bg" + messageColor[0].toUpperCase() + messageColor.slice(1)](msg);
        const override = this.config.overrideMessageOutput;
        const nextMessage = override ? override(logLevel, message, from) : [
            safe_1.default.grey(new Date().toISOString()),
            fgColor(logLevel.toUpperCase()),
            from ? bgColor(` ${from} `) : "",
            ...message
        ].filter(Boolean);
        console.log(...nextMessage);
        this.config.storage?.push({
            timestamp: Date.now(),
            level: logLevel,
            message: message.map(i => typeof i === "object" ? JSON.stringify(i) : i).join(" ")
        });
        safe_1.default.disable();
        return this.getJsonResponse(message, logLevel, from);
    }
}
exports.NodeLogger = NodeLogger;
